@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 
@@ -28,7 +28,8 @@ Task::Tags - Install the Tags modules.
 L<Tags>,
 L<Tags::Element>,
 L<Tags::Output::Indent>,
-L<Tags::Output::PYX>.
+L<Tags::Output::PYX>,
+L<Tags::Output::Structure>.
 
 =head1 REPOSITORY
 
@@ -48,6 +49,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
